#!/usr/bin/env python

#
# Implementation for user info controller.
#

from dm.common.objects.dmObject import DmObject
from dm.common.objects.dmObjectManager import DmObjectManager
from dm.common.db.api.userDbApi import UserDbApi
from dm.ds_web_service.service.impl.experimentManager import ExperimentManager

class UserInfoSessionControllerImpl(DmObjectManager):
    """ User info controller implementation class. """

    def __init__(self):
        DmObjectManager.__init__(self)
        self.userDbApi = UserDbApi()

    def getUsers(self):
        return self.userDbApi.getUsers()

    def getUserById(self, id):
        return self.userDbApi.getUserById(id)

    def getUserByUsername(self, username):
        return self.userDbApi.getUserByUsername(username)

    def addUser(self, username, firstName, lastName, middleName, email, badge, globusUsername, description, password, isLocalUser, lastUpdate):
        userInfo = self.userDbApi.addUser(username, firstName, lastName, middleName, email, badge, globusUsername, description, password, isLocalUser, lastUpdate)
        return userInfo

    def updateUser(self, id, username, firstName, lastName, middleName, email, badge, globusUsername, description, password, isLocalUser, lastUpdate):
        userInfo = self.userDbApi.updateUser(id, username, firstName, lastName, middleName, email, badge, globusUsername, description, password, isLocalUser, lastUpdate)
        return userInfo

    def addUserExperimentRole(self, username, experimentName, roleName):
        userInfo = self.userDbApi.addUserExperimentRole(username, experimentName, roleName)
        ExperimentManager.getInstance().addUserToGroup(username, experimentName)
        return userInfo

    def deleteUserExperimentRole(self, username, experimentName, roleName):
        userInfo = self.userDbApi.deleteUserExperimentRole(username, experimentName, roleName)
        ExperimentManager.getInstance().deleteUserFromGroup(username, experimentName)
        return userInfo

